@@ -33,23 +33,23 @@
 use crate::tests::{assert_decision, context};
 
 lazy_static! {
-  static ref DEFINITIONS: dmntk_model::model::Definitions = dmntk_model::parse(dmntk_examples::DMN_3_0005, "file: ///3_0005.dmn").unwrap();
+  static ref DEFINITIONS: dmntk_model::model::Definitions = dmntk_model::parse(dmntk_examples::DMN_2_0114, "file: ///2_0114.dmn").unwrap();
 }
 
 #[test]
 fn _0001() {
-  let ctx = context(r#"{Loan: {amount: 600000,rate: 0.0375,term: 360},fee: 100}"#);
-  assert_decision(&DEFINITIONS, "MonthlyPayment", &ctx, r#"2878.6935494327667680885203832"#);
+  let ctx = context(r#"{NumOfYears: 5}"#);
+  assert_decision(&DEFINITIONS, "CarInsurance", &ctx, r#"64.32"#);
 }
 
 #[test]
 fn _0002() {
-  let ctx = context(r#"{Loan: {amount: 30000,rate: 0.0475,term: 60},fee: 100}"#);
-  assert_decision(&DEFINITIONS, "MonthlyPayment", &ctx, r#"662.70735937326592715621433136"#);
+  let ctx = context(r#"{NumOfYears: 3}"#);
+  assert_decision(&DEFINITIONS, "CarInsurance", &ctx, r#"98.83"#);
 }
 
 #[test]
 fn _0003() {
-  let ctx = context(r#"{Loan: {amount: 600000,rate: 0.0399,term: 360},fee: 100}"#);
-  assert_decision(&DEFINITIONS, "MonthlyPayment", &ctx, r#"2961.03377700390163671626278"#);
+  let ctx = context(r#"{NumOfYears: 4}"#);
+  assert_decision(&DEFINITIONS, "CarInsurance", &ctx, r#"98.83"#);
 }
